DOMAIN := redxen.eu

IMAGE_OUTPUT := oci-archive.tar
BUILD_ID_OUT := build_id

# DNS
daemons/nsd/${BUILD_ID_OUT}: daemons/nsd/% : \
	daemons/nsd/nsd.conf \
	data/dns/%

data/dns/${BUILD_ID_OUT}: data/dns/% : \
	data/dns/redxen.eu \
	data/dnssec/% \
	data/opendkim/%

# Certificates
data/postgres-cert/${BUILD_ID_OUT}: data/postgres-cert/% : \
	data/postgres-cert/x509v3_config \
	data/postgres-cert/gen-cert.sh \
	data/ca/%

data/letsencrypt/${BUILD_ID_OUT}: data/letsencrypt/% : \
	data/letsencrypt/ca.crt \
	data/letsencrypt/public.crt \
	data/letsencrypt/secrets/private.key

data/selfsigned/${BUILD_ID_OUT}: data/selfsigned/% : \
	data/postgres-cert/x509v3_config \
	data/selfsigned/gen-cert.sh \
	data/ca/%

# Databases
daemons/postgres/${BUILD_ID_OUT}: daemons/postgres/% : \
	daemons/postgres/disable-hba-patcher.patch \
	daemons/postgres/postgresql.conf \
	daemons/postgres/init-db-hba.py \
	data/ca/% \
	data/postgres-cert/%

daemons/redis/${BUILD_ID_OUT}: daemons/redis/% : \
	daemons/redis/redis.conf

daemons/etcd/${BUILD_ID_OUT}: daemons/etcd/% : \
	data/ca/% \
	data/selfsigned/%

# Monitoring
daemons/grafana/${BUILD_ID_OUT}: daemons/grafana/% : \
	daemons/grafana/config.ini \
	data/ca/% \
	data/postgres-cert/%

daemons/prometheus/${BUILD_ID_OUT}: daemons/prometheus/% : \
	daemons/prometheus/config.yaml

# Mail
daemons/opendkim/${BUILD_ID_OUT}: daemons/opendkim/% : \
	daemons/opendkim/trusted_hosts \
	daemons/opendkim/opendkim.conf \
	data/opendkim/%

daemons/rspamd/${BUILD_ID_OUT}: daemons/rspamd/% : \
	daemons/rspamd/config/

daemons/dovecot/${BUILD_ID_OUT}: daemons/dovecot/% : \
	daemons/dovecot/automove.sieve \
	daemons/dovecot/dovecot.conf \
	daemons/dovecot/pgsql.conf \
	data/ca/% \
	data/postgres-cert/% \
	data/letsencrypt/%

daemons/postfix/${BUILD_ID_OUT}: daemons/postfix/% : \
	daemons/postfix/main.cf \
	daemons/postfix/master.cf \
	daemons/postfix/pgsql-aliases.cf \
	daemons/postfix/pgsql-users.cf \
	data/ca/% \
	data/postgres-cert/% \
	data/letsencrypt/%

# Other
daemons/murmurd/${BUILD_ID_OUT}: daemons/murmurd/% : \
	daemons/murmurd/murmur.ini \
	daemons/murmurd/secrets/mregpass \
	data/ca/% \
	data/postgres-cert/% \
	data/selfsigned/%
